# Redex

[![readthedocs](https://readthedocs.org/projects/redex/badge/?version=latest&style=flat)](https://redex.readthedocs.io)
[![codecov](https://codecov.io/gh/manifest/redex/branch/main/graph/badge.svg?token=QYJ9LU8634)](https://codecov.io/gh/manifest/redex)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black#readme)
[![Package version](https://shields.io/pypi/v/redex)](https://pypi.org/project/redex)

A combinator library for designing algorithms.
